@@ -1,6 +1,6 @@
 # pylint: disable=unused-import,missing-docstring
 
-from deepr.metrics.base import Metric
+from deepr.metrics.base import Metric, sanitize_metric_name
 from deepr.metrics.core import LastValue, MaxValue
 from deepr.metrics.step import StepCounter
 from deepr.metrics.mean import Mean, FiniteMean, DecayMean
